{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmo_bwa_mem"
            ],
            "label": "cmo-bwa-mem",
            "arguments": [
                {
                    "valueFrom": "0.7.5a",
                    "prefix": "--version",
                    "position": 0
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 16000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "run bwa mem\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT score for a sequence match [1]",
                    "inputBinding": {
                        "prefix": "-A"
                    },
                    "id": "#cmo-bwa-mem.cwl/A"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT penalty for a mismatch [4]",
                    "inputBinding": {
                        "prefix": "-B"
                    },
                    "id": "#cmo-bwa-mem.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "append FASTA/FASTQ comment to SAM output",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#cmo-bwa-mem.cwl/C"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT gap extension penalty; a gap of size k cost {-O} + {-E}*k [1]",
                    "inputBinding": {
                        "prefix": "-E"
                    },
                    "id": "#cmo-bwa-mem.cwl/E"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT penalty for clipping [5]",
                    "inputBinding": {
                        "prefix": "-L"
                    },
                    "id": "#cmo-bwa-mem.cwl/L"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "mark shorter split hits as secondary (for Picard/GATK compatibility)",
                    "inputBinding": {
                        "prefix": "-M"
                    },
                    "id": "#cmo-bwa-mem.cwl/M"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT gap open penalty [6]",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#cmo-bwa-mem.cwl/O"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "skip pairing; mate rescue performed unless -S also in use",
                    "inputBinding": {
                        "prefix": "-P"
                    },
                    "id": "#cmo-bwa-mem.cwl/P"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "STR read group header line such as '@RG\\tID -foo\\tSM -bar' [null]",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "id": "#cmo-bwa-mem.cwl/R"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "skip mate rescue",
                    "inputBinding": {
                        "prefix": "-S"
                    },
                    "id": "#cmo-bwa-mem.cwl/S"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT minimum score to output [30]",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#cmo-bwa-mem.cwl/T"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT penalty for an unpaired read pair [17]",
                    "inputBinding": {
                        "prefix": "-U"
                    },
                    "id": "#cmo-bwa-mem.cwl/U"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "output all alignments for SE or unpaired PE",
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#cmo-bwa-mem.cwl/a"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT skip seeds with more than INT occurrences [10000]",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#cmo-bwa-mem.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT off-diagonal X-dropoff [100]",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#cmo-bwa-mem.cwl/d"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--fastq1"
                    },
                    "id": "#cmo-bwa-mem.cwl/fastq1"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--fastq2"
                    },
                    "id": "#cmo-bwa-mem.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--genome"
                    },
                    "id": "#cmo-bwa-mem.cwl/genome"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT minimum seed length [19]",
                    "inputBinding": {
                        "prefix": "-k"
                    },
                    "id": "#cmo-bwa-mem.cwl/k"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#cmo-bwa-mem.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "first query file consists of interleaved paired-end sequences",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#cmo-bwa-mem.cwl/p"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FLOAT look for internal seeds inside a seed longer than {-k} * FLOAT [1.5]",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#cmo-bwa-mem.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Produce Sam instead of the default bam (Boolean)",
                    "inputBinding": {
                        "prefix": "--sam"
                    },
                    "id": "#cmo-bwa-mem.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT number of threads [1]",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "default": "6",
                    "id": "#cmo-bwa-mem.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT verbose level - 1=error, 2=warning, 3=message, 4+=debugging [3]",
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "id": "#cmo-bwa-mem.cwl/v"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "INT band width for banded alignment [100]",
                    "inputBinding": {
                        "prefix": "-w"
                    },
                    "id": "#cmo-bwa-mem.cwl/w"
                }
            ],
            "id": "#cmo-bwa-mem.cwl",
            "http://usefulinc.com/ns/doap#release": [
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cmo-bwa-mem",
                    "http://usefulinc.com/ns/doap#revision": "0.7.5a"
                },
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cwl-wrapper",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                }
            ],
            "http://purl.org/dc/terms/creator": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "http://purl.org/dc/terms/contributor": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output)\n    return inputs.output;\n  return null;\n}"
                    },
                    "id": "#cmo-bwa-mem.cwl/bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmo_picard"
            ],
            "label": "cmo-picard-AddOrReplaceReadGroups",
            "arguments": [
                {
                    "valueFrom": "AddOrReplaceReadGroups",
                    "prefix": "--cmd",
                    "position": 0
                },
                {
                    "valueFrom": "2.9",
                    "prefix": "--version",
                    "position": 0
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 8000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group sequencing center name Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGCN"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/CN"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--COMPRESSION_LEVEL"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/COMPRESSION_LEVEL"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--CREATE_INDEX"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/CREATE_INDEX"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--CREATE_MD5_FILE"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/CREATE_MD5_FILE"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group description Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGDS"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/DS"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group run date Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGDT"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/DT"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group flow order Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGFO"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/FO"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--INPUT"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/I"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group ID Default value - 1. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--RGID"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/ID"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group key sequence Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGKS"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/KS"
                },
                {
                    "type": "string",
                    "doc": "Read Group library Required.",
                    "inputBinding": {
                        "prefix": "--RGLB"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/LB"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--MAX_RECORDS_IN_RAM"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/MAX_RECORDS_IN_RAM"
                },
                {
                    "type": "string",
                    "doc": "Output file (BAM or SAM). Required.",
                    "inputBinding": {
                        "prefix": "--OUTPUT"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/O"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group program group Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGPG"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/PG"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group predicted insert size Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGPI"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/PI"
                },
                {
                    "type": "string",
                    "doc": "Read Group platform (e.g. illumina, solid) Required.",
                    "inputBinding": {
                        "prefix": "--RGPL"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/PL"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read Group platform model Default value - null.",
                    "inputBinding": {
                        "prefix": "--RGPM"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/PM"
                },
                {
                    "type": "string",
                    "doc": "Read Group platform unit (eg. run barcode) Required.",
                    "inputBinding": {
                        "prefix": "--RGPU"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/PU"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--QUIET"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/QUIET"
                },
                {
                    "type": "string",
                    "doc": "Read Group sample name Required.",
                    "inputBinding": {
                        "prefix": "--RGSM"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/SM"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional sort order to output in. If not supplied OUTPUT is in the same order as INPUT. Default value - null. Possible values - {unsorted, queryname, coordinate, duplicate, unknown}",
                    "inputBinding": {
                        "prefix": "--SORT_ORDER"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/SO"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--TMP_DIR"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/TMP_DIR"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--VALIDATION_STRINGENCY"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/VALIDATION_STRINGENCY"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--VERBOSITY"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/VERBOSITY"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stderr to file",
                    "inputBinding": {
                        "prefix": "--stderr"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/stderr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stdout to file",
                    "inputBinding": {
                        "prefix": "--stdout"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/stdout"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.O)\n    return inputs.O.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '').replace(/\\.bam/,'') + \".bai\";\n  return null;\n}"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/bai"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.O)\n    return inputs.O;\n  return null;\n}\n"
                    },
                    "id": "#cmo-picard.AddOrReplaceReadGroups.cwl/bam"
                }
            ],
            "id": "#cmo-picard.AddOrReplaceReadGroups.cwl",
            "http://usefulinc.com/ns/doap#release": [
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cmo-picard.AddOrReplaceReadGroups",
                    "http://usefulinc.com/ns/doap#revision": 2.9
                },
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cwl-wrapper",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                }
            ],
            "http://purl.org/dc/terms/creator": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "http://purl.org/dc/terms/contributor": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmo_picard"
            ],
            "label": "cmo-picard-MarkDuplicates",
            "arguments": [
                {
                    "valueFrom": "MarkDuplicates",
                    "prefix": "--cmd",
                    "position": 0
                },
                {
                    "valueFrom": "2.9",
                    "prefix": "--version",
                    "position": 0
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 32000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If true, assume that the input file is coordinate sorted even if the header says otherwise. Deprecated, used ASSUME_SORT_ORDER=coordinate instead. Default value - false. This option can be set to 'null' to clear the default value. Possible values - {true, false} Cannot be used in conjuction with option(s) ASSUME_SORT_ORDER (ASO)",
                    "inputBinding": {
                        "prefix": "--ASSUME_SORTED"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/AS"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If not null, assume that the input file has this order even if the header says otherwise. Default value - null. Possible values - {unsorted, queryname, coordinate, duplicate, unknown} Cannot be used in conjuction with option(s) ASSUME_SORTED (AS)",
                    "inputBinding": {
                        "prefix": "--ASSUME_SORT_ORDER"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/ASO"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Barcode SAM tag (ex. BC for 10X Genomics) Default value - null.",
                    "inputBinding": {
                        "prefix": "--BARCODE_TAG"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/BARCODE_TAG"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Clear DT tag from input SAM records. Should be set to false if input SAM doesn't have this tag. Default true Default value - true. This option can be set to 'null' to clear the default value. Possible values - {true, false}",
                    "inputBinding": {
                        "prefix": "--CLEAR_DT"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/CLEAR_DT"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Comment(s) to include in the output file's header. Default value - null. This option may be specified 0 or more times.",
                    "inputBinding": {
                        "prefix": "--COMMENT"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/CO"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--COMPRESSION_LEVEL"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/COMPRESSION_LEVEL"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--CREATE_INDEX"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/CREATE_INDEX"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--CREATE_MD5_FILE"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/CREATE_MD5_FILE"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The scoring strategy for choosing the non-duplicate among candidates. Default value - SUM_OF_BASE_QUALITIES. This option can be set to 'null' to clear the default value. Possible values - {SUM_OF_BASE_QUALITIES, TOTAL_MAPPED_REFERENCE_LENGTH, RANDOM}",
                    "inputBinding": {
                        "prefix": "--DUPLICATE_SCORING_STRATEGY"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/DS"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--I"
                            }
                        }
                    ],
                    "id": "#cmo-picard.MarkDuplicates.cwl/I"
                },
                {
                    "type": "string",
                    "doc": "File to write duplication metrics to Required.",
                    "inputBinding": {
                        "prefix": "--METRICS_FILE"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/M"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Maximum number of file handles to keep open when spilling read ends to disk. Set this number a little lower than the per-process maximum number of file that may be open. This number can be found by executing the 'ulimit -n' command on a Unix system. Default value - 8000. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--MAX_FILE_HANDLES_FOR_READ_ENDS_MAP"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/MAX_FILE_HANDLES"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "This number is the maximum size of a set of duplicate reads for which we will attempt to determine which are optical duplicates. Please be aware that if you raise this value too high and do encounter a very large set of duplicate reads, it will severely affect the runtime of this tool. To completely disable this check, set the value to -1. Default value - 300000. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--MAX_OPTICAL_DUPLICATE_SET_SIZE"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/MAX_OPTICAL_DUPLICATE_SET_SIZE"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--MAX_RECORDS_IN_RAM"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/MAX_RECORDS_IN_RAM"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "This option is obsolete. ReadEnds will always be spilled to disk. Default value - 50000. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--MAX_SEQUENCES_FOR_DISK_READ_ENDS_MAP"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/MAX_SEQS"
                },
                {
                    "type": "string",
                    "doc": "The output file to write marked records to Required.",
                    "inputBinding": {
                        "prefix": "--OUTPUT"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/O"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The maximum offset between two duplicate clusters in order to consider them optical duplicates. The default is appropriate for unpatterned versions of the Illumina platform. For the patterned flowcell models, 2500 is moreappropriate. For other platforms and models, users should experiment to find what works best. Default value - 100. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--OPTICAL_DUPLICATE_PIXEL_DISTANCE"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/OPTICAL_DUPLICATE_PIXEL_DISTANCE"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The program record ID for the @PG record(s) created by this program. Set to null to disable PG record creation. This string may have a suffix appended to avoid collision with other program record IDs. Default value - MarkDuplicates. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--PROGRAM_RECORD_ID"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/PG"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Value of CL tag of PG record to be created. If not supplied the command line will be detected automatically. Default value - null.",
                    "inputBinding": {
                        "prefix": "--PROGRAM_GROUP_COMMAND_LINE"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/PG_COMMAND"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Value of PN tag of PG record to be created. Default value - MarkDuplicates. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--PROGRAM_GROUP_NAME"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/PG_NAME"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Value of VN tag of PG record to be created. If not specified, the version will be detected automatically. Default value - null.",
                    "inputBinding": {
                        "prefix": "--PROGRAM_GROUP_VERSION"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/PG_VERSION"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--QUIET"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/QUIET"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Regular expression that can be used to parse read names in the incoming SAM file. Read names are parsed to extract three variables - tile/region, x coordinate and y coordinate. These values are used to estimate the rate of optical duplication in order to give a more accurate estimated library size. Set this option to null to disable optical duplicate detection, e.g. for RNA-seq or other data where duplicate sets are extremely large and estimating library complexity is not an aim. Note that without optical duplicate counts, library size estimation will be inaccurate. The regular expression should contain three capture groups for the three variables, in order. It must match the entire read name. Note that if the default regex is specified, a regex match is not actually done, but instead the read name is split on colon character. For 5 element names, the 3rd, 4th and 5th elements are assumed to be tile, x and y values. For 7 element names (CASAVA 1.8), the 5th, 6th, and 7th elements are assumed to be tile, x and y values. Default value - <optimized capture of last three ' -' separated fields as numeric values>. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--READ_NAME_REGEX"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/READ_NAME_REGEX"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read one barcode SAM tag (ex. BX for 10X Genomics) Default value - null.",
                    "inputBinding": {
                        "prefix": "--READ_ONE_BARCODE_TAG"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/READ_ONE_BARCODE_TAG"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Read two barcode SAM tag (ex. BX for 10X Genomics) Default value - null.",
                    "inputBinding": {
                        "prefix": "--READ_TWO_BARCODE_TAG"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/READ_TWO_BARCODE_TAG"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set. Default value - false. This option can be set to 'null' to clear the default value. Possible values - {true, false}",
                    "inputBinding": {
                        "prefix": "--REMOVE_DUPLICATES"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/REMOVE_DUPLICATES"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If true remove 'optical' duplicates and other duplicates that appear to have arisen from the sequencing process instead of the library preparation process, even if REMOVE_DUPLICATES is false. If REMOVE_DUPLICATES is true, all duplicates are removed and this option is ignored. Default value - false. This option can be set to 'null' to clear the default value. Possible values - {true, false}",
                    "inputBinding": {
                        "prefix": "--REMOVE_SEQUENCING_DUPLICATES"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/REMOVE_SEQUENCING_DUPLICATES"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "This number, plus the maximum RAM available to the JVM, determine the memory footprint used by some of the sorting collections. If you are running out of memory, try reducing this number. Default value - 0.25. This option can be set to 'null' to clear the default value.",
                    "inputBinding": {
                        "prefix": "--SORTING_COLLECTION_SIZE_RATIO"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/SORTING_COLLECTION_SIZE_RATIO"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Determines how duplicate types are recorded in the DT optional attribute. Default value - DontTag. This option can be set to 'null' to clear the default value. Possible values - {DontTag, OpticalOnly, All}",
                    "inputBinding": {
                        "prefix": "--TAGGING_POLICY"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/TAGGING_POLICY"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If a read appears in a duplicate set, add two tags. The first tag, DUPLICATE_SET_SIZE_TAG (DS), indicates the size of the duplicate set. The smallest possible DS value is 2 which occurs when two reads map to the same portion of the reference only one of which is marked as duplicate. The second tag, DUPLICATE_SET_INDEX_TAG (DI), represents a unique identifier for the duplicate set to which the record belongs. This identifier is the index-in-file of the representative read that was selected out of the duplicate set. Default value - false. This option can be set to 'null' to clear the default value. Possible values - {true, false}",
                    "inputBinding": {
                        "prefix": "--TAG_DUPLICATE_SET_MEMBERS"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/TAG_DUPLICATE_SET_MEMBERS"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--TMP_DIR"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/TMP_DIR"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--VALIDATION_STRINGENCY"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/VALIDATION_STRINGENCY"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--VERBOSITY"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/VERBOSITY"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stderr to file",
                    "inputBinding": {
                        "prefix": "--stderr"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/stderr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stdout to file",
                    "inputBinding": {
                        "prefix": "--stdout"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/stdout"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.O)\n    return inputs.O.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '').replace(/\\.bam/,'') + \".bai\";\n  return null;\n}\n"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/bai"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.O)\n    return inputs.O;\n  return null;\n}\n"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.M)\n    return inputs.M;\n  return null;\n}\n"
                    },
                    "id": "#cmo-picard.MarkDuplicates.cwl/mdmetrics"
                }
            ],
            "id": "#cmo-picard.MarkDuplicates.cwl",
            "http://usefulinc.com/ns/doap#release": [
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cmo-picard.MarkDuplicates",
                    "http://usefulinc.com/ns/doap#revision": 2.9
                },
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cwl-wrapper",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                }
            ],
            "http://purl.org/dc/terms/creator": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "http://purl.org/dc/terms/contributor": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmo_trimgalore"
            ],
            "label": "cmo-trimgalore",
            "arguments": [
                {
                    "valueFrom": "0.2.5.mod",
                    "prefix": "--version",
                    "position": 0
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var getBaseName = function(inputFile) { return inputFile.basename; };"
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000,
                    "coresMin": 1
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Adapter sequence to be trimmed. If not specified explicitely, the first 13 bp of the Illumina adapter 'AGATCGGAAGAGC' will be used by default.",
                    "inputBinding": {
                        "prefix": "--adapter"
                    },
                    "id": "#cmo-trimgalore.cwl/adapter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional adapter sequence to be trimmed off read 2 of paired-end files. This option requires '--paired' to be specified as well.",
                    "inputBinding": {
                        "prefix": "--adapter2"
                    },
                    "id": "#cmo-trimgalore.cwl/adapter2"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cmo-trimgalore.cwl/fastq1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cmo-trimgalore.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Run FastQC in the default mode on the FastQ file once trimming is complete.--fastqc_args \"<ARGS>\" Passes extra arguments to FastQC. If more than one argument is to be passed to FastQC they must be in the form \"arg1 arg2 etc.\". An example would be - --fastqc_args \"--nogroup --outdir /home/\". Passing extra arguments will automatically invoke FastQC, so --fastqc does not have to be specified separately.",
                    "inputBinding": {
                        "prefix": "--fastqc"
                    },
                    "id": "#cmo-trimgalore.cwl/fastqc"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Compress the output file with gzip. If the input files are gzip-compressed the output files will be automatically gzip compressed as well.",
                    "inputBinding": {
                        "prefix": "--gzip"
                    },
                    "id": "#cmo-trimgalore.cwl/gzip"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Keep the quality trimmed intermediate file. Default - off, which means the temporary file is being deleted after adapter trimming. Only has an effect for RRBS samples since other FastQ files are not trimmed for poor qualities separately.Note for RRBS using MseI -If your DNA material was digested with MseI (recognition motif - TTAA) instead of MspI it is NOT necessaryto specify --rrbs or --non_directional since virtually all reads should start with the sequence'TAA', and this holds true for both directional and non-directional libraries. As the end-repair of 'TAA'restricted sites does not involve any cytosines it does not need to be treated especially. Instead, simplyrun Trim Galore! in the standard (i.e. non-RRBS) mode.Paired-end specific options -",
                    "inputBinding": {
                        "prefix": "--keep"
                    },
                    "id": "#cmo-trimgalore.cwl/keep"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Discard reads that became shorter than length INT because of either quality or adapter trimming. A value of '0' effectively disables this behaviour. Default - 20 bp. For paired-end files, both reads of a read-pair need to be longer than <INT> bp to be printed out to validated paired-end files (see option --paired). If only one read became too short there is the possibility of keeping such unpaired single-end reads (see --retain_unpaired). Default pair-cutoff - 20 bp.",
                    "inputBinding": {
                        "prefix": "--length"
                    },
                    "default": "25",
                    "id": "#cmo-trimgalore.cwl/length"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Unpaired single-end read length cutoff needed for read 1 to be written to '.unpaired_1.fq' output file. These reads may be mapped in single-end mode. Default - 35 bp.",
                    "inputBinding": {
                        "prefix": "--length_1"
                    },
                    "id": "#cmo-trimgalore.cwl/length_1"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Unpaired single-end read length cutoff needed for read 2 to be written to '.unpaired_2.fq' output file. These reads may be mapped in single-end mode. Default - 35 bp.Last modified on 18 Oct 2012.",
                    "inputBinding": {
                        "prefix": "--length_2"
                    },
                    "id": "#cmo-trimgalore.cwl/length_2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "If specified no report file will be generated.",
                    "inputBinding": {
                        "prefix": "--no_report_file"
                    },
                    "id": "#cmo-trimgalore.cwl/no_report_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Selecting this option for non-directional RRBS libraries will screen quality-trimmed sequences for 'CAA' or 'CGA' at the start of the read and, if found, removes the first two basepairs. Like with the option '--rrbs' this avoids using cytosine positions that were filled-in during the end-repair step. '--non_directional' requires '--rrbs' to be specified as well.",
                    "inputBinding": {
                        "prefix": "--non_directional"
                    },
                    "id": "#cmo-trimgalore.cwl/non_directional"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If specified all output will be written to this directory instead of the current directory.",
                    "inputBinding": {
                        "prefix": "--output_dir"
                    },
                    "id": "#cmo-trimgalore.cwl/output_dir"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "This option performs length trimming of quality/adapter/RRBS trimmed reads for paired-end files. To pass the validation test, both sequences of a sequence pair are required to have a certain minimum length which is governed by the option --length (see above). If only one read passes this length threshold the other read can be rescued (see option --retain_unpaired). Using this option lets you discard too short read pairs without disturbing the sequence-by-sequence order of FastQ files which is required by many aligners. Trim Galore! expects paired-end files to be supplied in a pairwise fashion, e.g. file1_1.fq file1_2.fq SRR2_1.fq.gz SRR2_2.fq.gz ... .",
                    "inputBinding": {
                        "prefix": "--paired"
                    },
                    "id": "#cmo-trimgalore.cwl/paired"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Instructs Cutadapt to use ASCII+33 quality scores as Phred scores (Sanger/Illumina 1.9+ encoding) for quality trimming. Default - ON.",
                    "inputBinding": {
                        "prefix": "--phred33"
                    },
                    "id": "#cmo-trimgalore.cwl/phred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Instructs Cutadapt to use ASCII+64 quality scores as Phred scores (Illumina 1.5 encoding) for quality trimming.",
                    "inputBinding": {
                        "prefix": "--phred64"
                    },
                    "id": "#cmo-trimgalore.cwl/phred64"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Trim low-quality ends from reads in addition to adapter removal. For RRBS samples, quality trimming will be performed first, and adapter trimming is carried in a second round. Other files are quality and adapter trimmed in a single pass. The algorithm is the same as the one used by BWA (Subtract INT from all qualities; compute partial sums from all indices to the end of the sequence; cut sequence at the index at which the sum is minimal). Default Phred score - 20.",
                    "inputBinding": {
                        "prefix": "--quality"
                    },
                    "default": "1",
                    "id": "#cmo-trimgalore.cwl/quality"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "If only one of the two paired-end reads became too short, the longer read will be written to either '.unpaired_1.fq' or '.unpaired_2.fq' output files. The length cutoff for unpaired single-end reads is governed by the parameters -r1/--length_1 and -r2/--length_2. Default - OFF.",
                    "inputBinding": {
                        "prefix": "--retain_unpaired"
                    },
                    "id": "#cmo-trimgalore.cwl/retain_unpaired"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Specifies that the input file was an MspI digested RRBS sample (recognition site - CCGG). Sequences which were adapter-trimmed will have a further 2 bp removed from their 3' end. This is to avoid that the filled-in C close to the second MspI site in a sequence is used for methylation calls. Sequences which were merely trimmed because of poor quality will not be shortened further.",
                    "inputBinding": {
                        "prefix": "--rrbs"
                    },
                    "id": "#cmo-trimgalore.cwl/rrbs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stderr to file",
                    "inputBinding": {
                        "prefix": "--stderr"
                    },
                    "id": "#cmo-trimgalore.cwl/stderr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "log stdout to file",
                    "inputBinding": {
                        "prefix": "--stdout"
                    },
                    "id": "#cmo-trimgalore.cwl/stdout"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Overlap with adapter sequence required to trim a sequence. Defaults to a very stringent setting of '1', i.e. even a single bp of overlapping sequence will be trimmed of the 3' end of any read.-e <ERROR RATE> Maximum allowed error rate (no. of errors divided by the length of the matching region) (default - 0.1)",
                    "inputBinding": {
                        "prefix": "--stringency"
                    },
                    "id": "#cmo-trimgalore.cwl/stringency"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "If specified any output to STDOUT or STDERR will be suppressed.RRBS-specific options (MspI digested material) -",
                    "inputBinding": {
                        "prefix": "--suppress_warn"
                    },
                    "id": "#cmo-trimgalore.cwl/suppress_warn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "doc": "Trims 1 bp off every read from its 3' end. This may be needed for FastQ files that are to be aligned as paired-end data with Bowtie. This is because Bowtie (1) regards alignments like this - R1 ---------------------------> or this - -----------------------> R1 R2 <--------------------------- <----------------- R2 as invalid (whenever a start/end coordinate is contained within the other read).",
                    "inputBinding": {
                        "prefix": "--trim1"
                    },
                    "id": "#cmo-trimgalore.cwl/trim1"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.paired && inputs.fastq1)\n    return getBaseName(inputs.fastq1).replace(\".fastq.gz\", \"_cl.fastq.gz\");\n  return null;\n}\n"
                    },
                    "id": "#cmo-trimgalore.cwl/clfastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.paired && inputs.fastq2)\n    return getBaseName(inputs.fastq2).replace(\".fastq.gz\", \"_cl.fastq.gz\");\n  return null;\n}\n"
                    },
                    "id": "#cmo-trimgalore.cwl/clfastq2"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.paired && inputs.fastq1)\n    return getBaseName(inputs.fastq1).replace(\".fastq.gz\", \"_cl.stats\");\n  return null;\n}\n"
                    },
                    "id": "#cmo-trimgalore.cwl/clstats1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.paired && inputs.fastq2)\n    return getBaseName(inputs.fastq2).replace(\".fastq.gz\", \"_cl.stats\");\n  return null;\n}"
                    },
                    "id": "#cmo-trimgalore.cwl/clstats2"
                }
            ],
            "id": "#cmo-trimgalore.cwl",
            "http://usefulinc.com/ns/doap#release": [
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cmo-trimgalore",
                    "http://usefulinc.com/ns/doap#revision": "0.2.5.mod"
                },
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cwl-wrapper",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                }
            ],
            "http://purl.org/dc/terms/creator": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "http://purl.org/dc/terms/contributor": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "module-1",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/adapter"
                },
                {
                    "type": "string",
                    "id": "#main/adapter2"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_CN"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_ID"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_LB"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_PL"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_PU"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_SM"
                },
                {
                    "type": "string",
                    "id": "#main/add_rg_output"
                },
                {
                    "type": "string",
                    "id": "#main/bwa_output"
                },
                {
                    "type": "File",
                    "id": "#main/fastq1"
                },
                {
                    "type": "File",
                    "id": "#main/fastq2"
                },
                {
                    "type": "string",
                    "id": "#main/genome"
                },
                {
                    "type": "string",
                    "id": "#main/md_metrics_output"
                },
                {
                    "type": "string",
                    "id": "#main/md_output"
                },
                {
                    "type": "string",
                    "id": "#main/tmp_dir"
                }
            ],
            "steps": [
                {
                    "run": "#cmo-bwa-mem.cwl",
                    "in": [
                        {
                            "source": "#main/cmo-trimgalore/clfastq1",
                            "id": "#main/cmo-bwa-mem/fastq1"
                        },
                        {
                            "source": "#main/cmo-trimgalore/clfastq2",
                            "id": "#main/cmo-bwa-mem/fastq2"
                        },
                        {
                            "source": "#main/genome",
                            "id": "#main/cmo-bwa-mem/genome"
                        },
                        {
                            "source": "#main/bwa_output",
                            "id": "#main/cmo-bwa-mem/output"
                        }
                    ],
                    "out": [
                        "#main/cmo-bwa-mem/bam"
                    ],
                    "id": "#main/cmo-bwa-mem"
                },
                {
                    "run": "#cmo-picard.AddOrReplaceReadGroups.cwl",
                    "in": [
                        {
                            "source": "#main/add_rg_CN",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/CN"
                        },
                        {
                            "source": "#main/cmo-bwa-mem/bam",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/I"
                        },
                        {
                            "source": "#main/add_rg_ID",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/ID"
                        },
                        {
                            "source": "#main/add_rg_LB",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/LB"
                        },
                        {
                            "source": "#main/add_rg_output",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/O"
                        },
                        {
                            "source": "#main/add_rg_PL",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/PL"
                        },
                        {
                            "source": "#main/add_rg_PU",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/PU"
                        },
                        {
                            "source": "#main/add_rg_SM",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/SM"
                        },
                        {
                            "default": "coordinate",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/SO"
                        },
                        {
                            "source": "#main/tmp_dir",
                            "id": "#main/cmo-picard.AddOrReplaceReadGroups/TMP_DIR"
                        }
                    ],
                    "out": [
                        "#main/cmo-picard.AddOrReplaceReadGroups/bam",
                        "#main/cmo-picard.AddOrReplaceReadGroups/bai"
                    ],
                    "id": "#main/cmo-picard.AddOrReplaceReadGroups"
                },
                {
                    "run": "#cmo-picard.MarkDuplicates.cwl",
                    "in": [
                        {
                            "source": "#main/cmo-picard.AddOrReplaceReadGroups/bam",
                            "valueFrom": "${ return [self]; }",
                            "id": "#main/cmo-picard.MarkDuplicates/I"
                        },
                        {
                            "source": "#main/md_metrics_output",
                            "id": "#main/cmo-picard.MarkDuplicates/M"
                        },
                        {
                            "source": "#main/md_output",
                            "id": "#main/cmo-picard.MarkDuplicates/O"
                        },
                        {
                            "source": "#main/tmp_dir",
                            "id": "#main/cmo-picard.MarkDuplicates/TMP_DIR"
                        }
                    ],
                    "out": [
                        "#main/cmo-picard.MarkDuplicates/bam",
                        "#main/cmo-picard.MarkDuplicates/bai",
                        "#main/cmo-picard.MarkDuplicates/mdmetrics"
                    ],
                    "id": "#main/cmo-picard.MarkDuplicates"
                },
                {
                    "run": "#cmo-trimgalore.cwl",
                    "in": [
                        {
                            "source": "#main/adapter",
                            "id": "#main/cmo-trimgalore/adapter"
                        },
                        {
                            "source": "#main/adapter2",
                            "id": "#main/cmo-trimgalore/adapter2"
                        },
                        {
                            "source": "#main/fastq1",
                            "id": "#main/cmo-trimgalore/fastq1"
                        },
                        {
                            "source": "#main/fastq2",
                            "id": "#main/cmo-trimgalore/fastq2"
                        }
                    ],
                    "out": [
                        "#main/cmo-trimgalore/clfastq1",
                        "#main/cmo-trimgalore/clfastq2",
                        "#main/cmo-trimgalore/clstats1",
                        "#main/cmo-trimgalore/clstats2"
                    ],
                    "id": "#main/cmo-trimgalore"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/cmo-picard.MarkDuplicates/bai",
                    "id": "#main/bai"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cmo-picard.MarkDuplicates/bam",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cmo-trimgalore/clstats1",
                    "id": "#main/clstats1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cmo-trimgalore/clstats2",
                    "id": "#main/clstats2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cmo-picard.MarkDuplicates/mdmetrics",
                    "id": "#main/md_metrics"
                }
            ],
            "id": "#main",
            "http://usefulinc.com/ns/doap#release": [
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "module-1",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                },
                {
                    "class": "http://usefulinc.com/ns/doap#Version",
                    "http://usefulinc.com/ns/doap#name": "cwl-wrapper",
                    "http://usefulinc.com/ns/doap#revision": "1.0.0"
                }
            ],
            "http://purl.org/dc/terms/creator": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ],
            "http://purl.org/dc/terms/contributor": [
                {
                    "class": "http://xmlns.com/foaf/0.1/Organization",
                    "http://xmlns.com/foaf/0.1/name": "Memorial Sloan Kettering Cancer Center",
                    "http://xmlns.com/foaf/0.1/member": [
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Christopher Harris",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:harrisc2@mskcc.org"
                        },
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Ronak H. Shah",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:shahr2@mskcc.org"
                        },
                        {
                            "class": "http://xmlns.com/foaf/0.1/Person",
                            "http://xmlns.com/foaf/0.1/name": "Jaeyoung Chun",
                            "http://xmlns.com/foaf/0.1/mbox": "mailto:chunj@mskcc.org"
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://xmlns.com/foaf/spec/20140114.rdf",
        "http://dublincore.org/2012/06/14/dcterms.rdf",
        "http://usefulinc.com/ns/doap#"
    ],
    "$namespaces": {
        "dct": "http://purl.org/dc/terms/",
        "foaf": "http://xmlns.com/foaf/0.1/",
        "doap": "http://usefulinc.com/ns/doap#"
    }
}
